// Copyright 2018 JDCLOUD.COM
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// NOTE: This class is auto generated by the jdcloud code generator program.

package models

type Actionlog struct {

	/* 操作记录的ID (Optional) */
	Id int `json:"id"`

	/* 用户名 (Optional) */
	UserPin string `json:"userPin"`

	/* 操作的域名 (Optional) */
	Domain string `json:"domain"`

	/* 操作类型：1新增 2修改 3删除 (Optional) */
	Type int `json:"type"`

	/* 操作的详细情况 (Optional) */
	Detail string `json:"detail"`

	/* 操作发生的时间 (Optional) */
	Time int64 `json:"time"`

	/* 操作的结果，成功true, 失败false (Optional) */
	Success bool `json:"success"`

	/* 操作失败的原因 (Optional) */
	FailReason string `json:"failReason"`

	/* 操作者的IP (Optional) */
	ClientIp string `json:"clientIp"`
}
