package ucloud

import "github.com/ucloud/ucloud-sdk-go/ucloud/config"

// Config is the config of ucloud sdk, use for setting up client
type Config = config.Config

// NewConfig will return a new client config with default options.
var NewConfig = config.NewConfig
