// This file is auto-generated, don't edit it. Thanks.
package client

import (
	"github.com/alibabacloud-go/tea/dara"
)

type iCreateScheduledPreloadExecutionsShrinkRequest interface {
	dara.Model
	String() string
	GoString() string
	SetExecutionsShrink(v string) *CreateScheduledPreloadExecutionsShrinkRequest
	GetExecutionsShrink() *string
	SetId(v string) *CreateScheduledPreloadExecutionsShrinkRequest
	GetId() *string
}

type CreateScheduledPreloadExecutionsShrinkRequest struct {
	// The scheduled prefetch plans to create.
	//
	// This parameter is required.
	ExecutionsShrink *string `json:"Executions,omitempty" xml:"Executions,omitempty"`
	// The ID of the prefetch task, which is generated by calling the [CreateScheduledPreloadJob](https://help.aliyun.com/document_detail/2850459.html) operation.
	//
	// example:
	//
	// CreateScheduledPreloadExecutions
	Id *string `json:"Id,omitempty" xml:"Id,omitempty"`
}

func (s CreateScheduledPreloadExecutionsShrinkRequest) String() string {
	return dara.Prettify(s)
}

func (s CreateScheduledPreloadExecutionsShrinkRequest) GoString() string {
	return s.String()
}

func (s *CreateScheduledPreloadExecutionsShrinkRequest) GetExecutionsShrink() *string {
	return s.ExecutionsShrink
}

func (s *CreateScheduledPreloadExecutionsShrinkRequest) GetId() *string {
	return s.Id
}

func (s *CreateScheduledPreloadExecutionsShrinkRequest) SetExecutionsShrink(v string) *CreateScheduledPreloadExecutionsShrinkRequest {
	s.ExecutionsShrink = &v
	return s
}

func (s *CreateScheduledPreloadExecutionsShrinkRequest) SetId(v string) *CreateScheduledPreloadExecutionsShrinkRequest {
	s.Id = &v
	return s
}

func (s *CreateScheduledPreloadExecutionsShrinkRequest) Validate() error {
	return dara.Validate(s)
}
