// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v3.21.12
// source: yandex/cloud/dns/v1/dns_endpoint.proto

package dns

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type DnsInboundEndpoint_Status int32

const (
	// Status is not specified.
	DnsInboundEndpoint_STATUS_UNSPECIFIED DnsInboundEndpoint_Status = 0
	// Endpoint is being created.
	DnsInboundEndpoint_PENDING DnsInboundEndpoint_Status = 1
	// Endpoint is ready to use.
	DnsInboundEndpoint_AVAILABLE DnsInboundEndpoint_Status = 2
	// Endpoint is being deleted.
	DnsInboundEndpoint_DELETING DnsInboundEndpoint_Status = 3
)

// Enum value maps for DnsInboundEndpoint_Status.
var (
	DnsInboundEndpoint_Status_name = map[int32]string{
		0: "STATUS_UNSPECIFIED",
		1: "PENDING",
		2: "AVAILABLE",
		3: "DELETING",
	}
	DnsInboundEndpoint_Status_value = map[string]int32{
		"STATUS_UNSPECIFIED": 0,
		"PENDING":            1,
		"AVAILABLE":          2,
		"DELETING":           3,
	}
)

func (x DnsInboundEndpoint_Status) Enum() *DnsInboundEndpoint_Status {
	p := new(DnsInboundEndpoint_Status)
	*p = x
	return p
}

func (x DnsInboundEndpoint_Status) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (DnsInboundEndpoint_Status) Descriptor() protoreflect.EnumDescriptor {
	return file_yandex_cloud_dns_v1_dns_endpoint_proto_enumTypes[0].Descriptor()
}

func (DnsInboundEndpoint_Status) Type() protoreflect.EnumType {
	return &file_yandex_cloud_dns_v1_dns_endpoint_proto_enumTypes[0]
}

func (x DnsInboundEndpoint_Status) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use DnsInboundEndpoint_Status.Descriptor instead.
func (DnsInboundEndpoint_Status) EnumDescriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDescGZIP(), []int{0, 0}
}

type DnsInboundEndpoint struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS inbound endpoint. Generated at creation time.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// ID of the folder that the DNS inbound endpoint belongs to.
	FolderId string `protobuf:"bytes,2,opt,name=folder_id,json=folderId,proto3" json:"folder_id,omitempty"`
	// Creation timestamp.
	CreatedAt *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	// Name of the DNS inbound endpoint.
	// The name is unique within the folder.
	Name string `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// Description of the DNS inbound endpoint.
	Description string `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
	// DNS inbound endpoint labels as `key:value` pairs.
	Labels map[string]string `protobuf:"bytes,6,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	// ID of the network that the DNS inbound endpoint belongs to.
	NetworkId string `protobuf:"bytes,7,opt,name=network_id,json=networkId,proto3" json:"network_id,omitempty"`
	// IP address of the DNS inbound endpoint.
	Address string `protobuf:"bytes,8,opt,name=address,proto3" json:"address,omitempty"`
	// ID of the address resource.
	AddressId string `protobuf:"bytes,9,opt,name=address_id,json=addressId,proto3" json:"address_id,omitempty"`
	// Status of the DNS inbound endpoint.
	Status DnsInboundEndpoint_Status `protobuf:"varint,10,opt,name=status,proto3,enum=yandex.cloud.dns.v1.DnsInboundEndpoint_Status" json:"status,omitempty"`
	// Prevents accidental endpoint removal.
	DeletionProtection bool `protobuf:"varint,11,opt,name=deletion_protection,json=deletionProtection,proto3" json:"deletion_protection,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *DnsInboundEndpoint) Reset() {
	*x = DnsInboundEndpoint{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DnsInboundEndpoint) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DnsInboundEndpoint) ProtoMessage() {}

func (x *DnsInboundEndpoint) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DnsInboundEndpoint.ProtoReflect.Descriptor instead.
func (*DnsInboundEndpoint) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDescGZIP(), []int{0}
}

func (x *DnsInboundEndpoint) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *DnsInboundEndpoint) GetFolderId() string {
	if x != nil {
		return x.FolderId
	}
	return ""
}

func (x *DnsInboundEndpoint) GetCreatedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.CreatedAt
	}
	return nil
}

func (x *DnsInboundEndpoint) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *DnsInboundEndpoint) GetDescription() string {
	if x != nil {
		return x.Description
	}
	return ""
}

func (x *DnsInboundEndpoint) GetLabels() map[string]string {
	if x != nil {
		return x.Labels
	}
	return nil
}

func (x *DnsInboundEndpoint) GetNetworkId() string {
	if x != nil {
		return x.NetworkId
	}
	return ""
}

func (x *DnsInboundEndpoint) GetAddress() string {
	if x != nil {
		return x.Address
	}
	return ""
}

func (x *DnsInboundEndpoint) GetAddressId() string {
	if x != nil {
		return x.AddressId
	}
	return ""
}

func (x *DnsInboundEndpoint) GetStatus() DnsInboundEndpoint_Status {
	if x != nil {
		return x.Status
	}
	return DnsInboundEndpoint_STATUS_UNSPECIFIED
}

func (x *DnsInboundEndpoint) GetDeletionProtection() bool {
	if x != nil {
		return x.DeletionProtection
	}
	return false
}

var File_yandex_cloud_dns_v1_dns_endpoint_proto protoreflect.FileDescriptor

const file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDesc = "" +
	"\n" +
	"&yandex/cloud/dns/v1/dns_endpoint.proto\x12\x13yandex.cloud.dns.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd7\x04\n" +
	"\x12DnsInboundEndpoint\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12\x1b\n" +
	"\tfolder_id\x18\x02 \x01(\tR\bfolderId\x129\n" +
	"\n" +
	"created_at\x18\x03 \x01(\v2\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x12\n" +
	"\x04name\x18\x04 \x01(\tR\x04name\x12 \n" +
	"\vdescription\x18\x05 \x01(\tR\vdescription\x12K\n" +
	"\x06labels\x18\x06 \x03(\v23.yandex.cloud.dns.v1.DnsInboundEndpoint.LabelsEntryR\x06labels\x12\x1d\n" +
	"\n" +
	"network_id\x18\a \x01(\tR\tnetworkId\x12\x18\n" +
	"\aaddress\x18\b \x01(\tR\aaddress\x12\x1d\n" +
	"\n" +
	"address_id\x18\t \x01(\tR\taddressId\x12F\n" +
	"\x06status\x18\n" +
	" \x01(\x0e2..yandex.cloud.dns.v1.DnsInboundEndpoint.StatusR\x06status\x12/\n" +
	"\x13deletion_protection\x18\v \x01(\bR\x12deletionProtection\x1a9\n" +
	"\vLabelsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01\"J\n" +
	"\x06Status\x12\x16\n" +
	"\x12STATUS_UNSPECIFIED\x10\x00\x12\v\n" +
	"\aPENDING\x10\x01\x12\r\n" +
	"\tAVAILABLE\x10\x02\x12\f\n" +
	"\bDELETING\x10\x03BV\n" +
	"\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3"

var (
	file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDescOnce sync.Once
	file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDescData []byte
)

func file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDescGZIP() []byte {
	file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDescOnce.Do(func() {
		file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDesc), len(file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDesc)))
	})
	return file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDescData
}

var file_yandex_cloud_dns_v1_dns_endpoint_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_yandex_cloud_dns_v1_dns_endpoint_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_yandex_cloud_dns_v1_dns_endpoint_proto_goTypes = []any{
	(DnsInboundEndpoint_Status)(0), // 0: yandex.cloud.dns.v1.DnsInboundEndpoint.Status
	(*DnsInboundEndpoint)(nil),     // 1: yandex.cloud.dns.v1.DnsInboundEndpoint
	nil,                            // 2: yandex.cloud.dns.v1.DnsInboundEndpoint.LabelsEntry
	(*timestamppb.Timestamp)(nil),  // 3: google.protobuf.Timestamp
}
var file_yandex_cloud_dns_v1_dns_endpoint_proto_depIdxs = []int32{
	3, // 0: yandex.cloud.dns.v1.DnsInboundEndpoint.created_at:type_name -> google.protobuf.Timestamp
	2, // 1: yandex.cloud.dns.v1.DnsInboundEndpoint.labels:type_name -> yandex.cloud.dns.v1.DnsInboundEndpoint.LabelsEntry
	0, // 2: yandex.cloud.dns.v1.DnsInboundEndpoint.status:type_name -> yandex.cloud.dns.v1.DnsInboundEndpoint.Status
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_yandex_cloud_dns_v1_dns_endpoint_proto_init() }
func file_yandex_cloud_dns_v1_dns_endpoint_proto_init() {
	if File_yandex_cloud_dns_v1_dns_endpoint_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDesc), len(file_yandex_cloud_dns_v1_dns_endpoint_proto_rawDesc)),
			NumEnums:      1,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_yandex_cloud_dns_v1_dns_endpoint_proto_goTypes,
		DependencyIndexes: file_yandex_cloud_dns_v1_dns_endpoint_proto_depIdxs,
		EnumInfos:         file_yandex_cloud_dns_v1_dns_endpoint_proto_enumTypes,
		MessageInfos:      file_yandex_cloud_dns_v1_dns_endpoint_proto_msgTypes,
	}.Build()
	File_yandex_cloud_dns_v1_dns_endpoint_proto = out.File
	file_yandex_cloud_dns_v1_dns_endpoint_proto_goTypes = nil
	file_yandex_cloud_dns_v1_dns_endpoint_proto_depIdxs = nil
}
