// Copyright 2017 Microsoft Corporation. All rights reserved.
// Use of this source code is governed by an MIT
// license that can be found in the LICENSE file.

// Package arm contains functionality specific to Azure Resource Manager clients.
package arm
