// Copyright 2018 JDCLOUD.COM
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// NOTE: This class is auto generated by the jdcloud code generator program.

package models

type MonitorAlarmInfo struct {

	/* 域名ID (Optional) */
	DomainId int `json:"domainId"`

	/* 子域名 (Optional) */
	SubDomainName string `json:"subDomainName"`

	/* 故障IP/域名 (Optional) */
	Host string `json:"host"`

	/* null (Optional) */
	Id int `json:"id"`

	/* 故障开始时间，格式Unix timestamp，时间单位：毫秒 (Optional) */
	StartTime int64 `json:"startTime"`

	/* 故障结束时间，格式Unix timestamp，时间单位：毫秒 (Optional) */
	EndTime int64 `json:"endTime"`
}
